@@ -87,8 +87,8 @@ class FileServerConnector:
         answer = await self._connector.get("/file/info", args, headers=self._construct_headers())
         return dict_to_dataclass(answer, FileLink)
 
-    async def add_file(self, file: bytes, filename: str, is_create_thumbnail: bool = False) -> FileLink:
-        args = {"filename": filename, "is_create_thumbnail": is_create_thumbnail}
+    async def add_file(self, file: bytes, filename: str, is_thumbnail_required: bool = False) -> FileLink:
+        args = {"filename": filename, "is_thumbnail_required": is_thumbnail_required}
         answer = await self._connector.post("/file/add", payload=file, url_query=args,
                                             headers=self._construct_headers())
         return dict_to_dataclass(answer, FileLink)
